{
  "cells": [
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "# Simulation of geometric-temporal\n",
        "\n",
        "SEOYEON CHOI  \n",
        "2022-12-28\n",
        "\n",
        "> Simulation\n",
        "\n",
        "https://pytorch-geometric-temporal.readthedocs.io/en/latest/modules/dataset.html#module-torch_geometric_temporal.dataset.chickenpox\n",
        "\n",
        "### import"
      ],
      "id": "5fe45bea-4dab-425e-bae4-13df17f8d298"
    },
    {
      "cell_type": "code",
      "execution_count": 10,
      "metadata": {},
      "outputs": [],
      "source": [
        "import networkx as nx\n",
        "import numpy as np\n",
        "import matplotlib.pyplot as plt\n",
        "import pandas as pd\n",
        "import torch"
      ],
      "id": "53102b65-f60e-4102-898e-ab40654a5c99"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "### 공식 홈페이지 예제\n",
        "\n",
        "#### data"
      ],
      "id": "a6e1460a-9e73-41d9-964d-fb0dfdb296c2"
    },
    {
      "cell_type": "code",
      "execution_count": 11,
      "metadata": {},
      "outputs": [],
      "source": [
        "from torch_geometric_temporal.dataset import WikiMathsDatasetLoader\n",
        "from torch_geometric_temporal.signal import temporal_signal_split\n",
        "\n",
        "loader = WikiMathsDatasetLoader()\n",
        "\n",
        "dataset = loader.get_dataset(lags=14)\n",
        "\n",
        "train_dataset, test_dataset = temporal_signal_split(dataset, train_ratio=0.5)"
      ],
      "id": "378bcabf-49b6-4de4-8a91-9eb93343e2be"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "#### RecurrentGCN"
      ],
      "id": "4d685fdc-b2d1-407f-b40a-cc3dbdcc641a"
    },
    {
      "cell_type": "code",
      "execution_count": 12,
      "metadata": {},
      "outputs": [],
      "source": [
        "import torch\n",
        "import torch.nn.functional as F\n",
        "from torch_geometric_temporal.nn.recurrent import GConvGRU\n",
        "\n",
        "class RecurrentGCN(torch.nn.Module):\n",
        "    def __init__(self, node_features, filters):\n",
        "        super(RecurrentGCN, self).__init__()\n",
        "        self.recurrent = GConvGRU(node_features, filters, 2)\n",
        "        self.linear = torch.nn.Linear(filters, 1)\n",
        "\n",
        "    def forward(self, x, edge_index, edge_weight):\n",
        "        h = self.recurrent(x, edge_index, edge_weight)\n",
        "        h = F.relu(h)\n",
        "        h = self.linear(h)\n",
        "        return h"
      ],
      "id": "5903a058-a6e4-43cd-8180-438999a28820"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "#### Learn"
      ],
      "id": "30828bbe-5705-47f3-bc9b-02e3f7ea8185"
    },
    {
      "cell_type": "code",
      "execution_count": 13,
      "metadata": {},
      "outputs": [
        {
          "output_type": "stream",
          "name": "stderr",
          "text": [
            "100%|██████████| 1/1 [00:11<00:00, 11.93s/it]"
          ]
        }
      ],
      "source": [
        "from tqdm import tqdm\n",
        "\n",
        "model = RecurrentGCN(node_features=14, filters=32)\n",
        "\n",
        "optimizer = torch.optim.Adam(model.parameters(), lr=0.01)\n",
        "\n",
        "model.train()\n",
        "\n",
        "for epoch in tqdm(range(1)):\n",
        "    for time, snapshot in enumerate(train_dataset):\n",
        "        y_hat = model(snapshot.x, snapshot.edge_index, snapshot.edge_attr)\n",
        "        cost = torch.mean((y_hat-snapshot.y)**2)\n",
        "        cost.backward()\n",
        "        optimizer.step()\n",
        "        optimizer.zero_grad()"
      ],
      "id": "bdf219dc-463f-4af7-81a2-18812b5315cc"
    },
    {
      "cell_type": "code",
      "execution_count": 14,
      "metadata": {},
      "outputs": [],
      "source": [
        "for time, snapshot in enumerate(train_dataset):\n",
        "    _x = snapshot.x \n",
        "    _edge_index = snapshot.edge_index \n",
        "    _edge_attr = snapshot.edge_attr\n",
        "    _y = snapshot.y\n",
        "    break"
      ],
      "id": "09f9fb33-d853-49a5-93c5-677e48e6cb9c"
    },
    {
      "cell_type": "code",
      "execution_count": 15,
      "metadata": {},
      "outputs": [],
      "source": [
        "_x.shape"
      ],
      "id": "b4f164e1-7951-4162-827a-9943fcdbe205"
    },
    {
      "cell_type": "code",
      "execution_count": 18,
      "metadata": {},
      "outputs": [],
      "source": [
        "snapshot.y.shape"
      ],
      "id": "7d98cd96-3e89-4405-b0a4-b8399bd97200"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "-   1068개의 nodes\n",
        "-   한 개의 node에 mapping된 차원의 수"
      ],
      "id": "0fa55898-ed99-4627-a442-bd000b7566fd"
    },
    {
      "cell_type": "code",
      "execution_count": 7,
      "metadata": {},
      "outputs": [],
      "source": [
        "_edge_index.shape"
      ],
      "id": "9d137d7a-1e8d-48ef-8a95-8936576a5e81"
    },
    {
      "cell_type": "code",
      "execution_count": 8,
      "metadata": {},
      "outputs": [],
      "source": [
        "_edge_attr.shape"
      ],
      "id": "86e9c9ef-2b23-4001-84b5-b7c540dd5c3c"
    },
    {
      "cell_type": "code",
      "execution_count": 9,
      "metadata": {},
      "outputs": [],
      "source": [
        "_y.shape"
      ],
      "id": "27f719c2-5a4d-41ce-b190-71c895af15c2"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "### 우리 예제"
      ],
      "id": "fcb20fd8-1981-4c79-b5e9-e10a5e256216"
    },
    {
      "cell_type": "code",
      "execution_count": 34,
      "metadata": {},
      "outputs": [],
      "source": [
        "import numpy as np\n",
        "import matplotlib.pyplot as plt\n",
        "import pandas as pd\n",
        "import torch"
      ],
      "id": "e4def0f7-5515-4505-ab85-8168aa6a92bb"
    },
    {
      "cell_type": "code",
      "execution_count": 245,
      "metadata": {},
      "outputs": [],
      "source": [
        "T = 100\n",
        "N = 4 # number of Nodes\n",
        "E = np.array([[0,1],[1,2],[2,3],[3,0]]).T\n",
        "V = np.array([1,2,3,4])\n",
        "AMP = np.array([3,2,1,2.2])\n",
        "t = np.arange(0,T)\n",
        "node_features = 1"
      ],
      "id": "5f64b3e0-814e-4c95-bed8-8073bac63055"
    },
    {
      "cell_type": "code",
      "execution_count": 13,
      "metadata": {},
      "outputs": [],
      "source": [
        "f = np.stack([a*np.sin(2*t**2/1000)+np.random.normal(loc=0,scale=0.2,size=T) for a in AMP],axis=1).reshape(T,N,node_features)\n",
        "f = torch.tensor(f).float()"
      ],
      "id": "fcb2c753-0b71-44c8-9e10-5106659e0cdc"
    },
    {
      "cell_type": "code",
      "execution_count": 14,
      "metadata": {},
      "outputs": [],
      "source": [
        "f.shape"
      ],
      "id": "5597025f-e98e-4b8e-9e9b-de14246de86e"
    },
    {
      "cell_type": "code",
      "execution_count": 15,
      "metadata": {},
      "outputs": [],
      "source": [
        "X = f[:99,:,:]\n",
        "y = f[1:,:,:]"
      ],
      "id": "8ab0c01d-ed24-4e5e-bffe-18f45534b0c9"
    },
    {
      "cell_type": "code",
      "execution_count": 16,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXMAAAD4CAYAAAAeugY9AAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\nMT5gYW6MMT5gYW6MMT7wf2EWnzKuHx8DAAAAAElFTkSuQmCC\n"
          }
        }
      ],
      "source": [
        "plt.plot(y[:,0,0],label=\"v1\")\n",
        "plt.plot(y[:,1,0],label=\"v2\")\n",
        "plt.plot(y[:,2,0],label=\"v3\")\n",
        "plt.plot(y[:,3,0],label=\"v4\")\n",
        "plt.legend()"
      ],
      "id": "55422d1c-2260-42b6-beec-dc72f0c4b3c7"
    },
    {
      "cell_type": "code",
      "execution_count": 17,
      "metadata": {},
      "outputs": [],
      "source": [
        "edge_index = torch.tensor(E)\n",
        "edge_attr = torch.tensor(np.array([1,1,1,1]),dtype=torch.float32)"
      ],
      "id": "1b61dc12-09ce-4899-aa82-7991a4de71e3"
    },
    {
      "cell_type": "code",
      "execution_count": 18,
      "metadata": {},
      "outputs": [],
      "source": [
        "_ee = enumerate(zip(X,y))"
      ],
      "id": "4397b569-7a6d-4752-b3f4-88ade176d416"
    },
    {
      "cell_type": "code",
      "execution_count": 19,
      "metadata": {},
      "outputs": [
        {
          "output_type": "stream",
          "name": "stderr",
          "text": [
            "100%|██████████| 50/50 [00:16<00:00,  3.01it/s]"
          ]
        }
      ],
      "source": [
        "from tqdm import tqdm\n",
        "\n",
        "model = RecurrentGCN(node_features=1, filters=4)\n",
        "\n",
        "optimizer = torch.optim.Adam(model.parameters(), lr=0.01)\n",
        "\n",
        "model.train()\n",
        "\n",
        "for epoch in tqdm(range(50)):\n",
        "    for time, (xt,yt) in enumerate(zip(X,y)):\n",
        "        y_hat = model(xt, edge_index, edge_attr)\n",
        "        cost = torch.mean((y_hat-yt)**2)\n",
        "        cost.backward()\n",
        "        optimizer.step()\n",
        "        optimizer.zero_grad()"
      ],
      "id": "9057aa39-cba5-477b-b62b-ac652789f75a"
    },
    {
      "cell_type": "code",
      "execution_count": 20,
      "metadata": {},
      "outputs": [],
      "source": [
        "yhat = torch.stack([model(xt, edge_index, edge_attr) for xt in X]).detach().numpy()"
      ],
      "id": "991ae985-0e54-4897-9b87-3f7007788aa9"
    },
    {
      "cell_type": "code",
      "execution_count": 21,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXMAAAD4CAYAAAAeugY9AAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\njSYD0GKu0Wg0GYAWc41Go8kA/j8wfUPpf4r/AAAAAABJRU5ErkJggg==\n"
          }
        }
      ],
      "source": [
        "plt.plot(y[:,0,0],label=\"y in V1\")\n",
        "plt.plot(yhat[:,0,0],label=\"yhat in V1\")\n",
        "plt.legend()"
      ],
      "id": "505fd161-518b-422e-8bd5-e48d88613221"
    },
    {
      "cell_type": "code",
      "execution_count": 22,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXMAAAD4CAYAAAAeugY9AAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\ni7lGo9HMAbSYazQazRzg/wfoIB0YD1M6MQAAAABJRU5ErkJggg==\n"
          }
        }
      ],
      "source": [
        "plt.plot(y[:,1,0],label=\"y in V2\")\n",
        "plt.plot(yhat[:,1,0],label=\"yhat in V2\")\n",
        "plt.legend()"
      ],
      "id": "e4e9c7bc-bad9-48d1-8622-7af46291effd"
    },
    {
      "cell_type": "code",
      "execution_count": 23,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAX0AAAD4CAYAAAAAczaOAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\nAAAAAElFTkSuQmCC\n"
          }
        }
      ],
      "source": [
        "plt.plot(y[:,2,0],label=\"y in V3\")\n",
        "plt.plot(yhat[:,2,0],label=\"yhat in V3\")\n",
        "plt.legend()"
      ],
      "id": "4df8b299-6272-4643-a7cc-ba1c52bc519c"
    },
    {
      "cell_type": "code",
      "execution_count": 24,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXMAAAD4CAYAAAAeugY9AAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\nvQAAAABJRU5ErkJggg==\n"
          }
        }
      ],
      "source": [
        "plt.plot(y[:,3,0],label=\"y in V4\")\n",
        "plt.plot(yhat[:,3,0],label=\"yhat in V4\")\n",
        "plt.legend()"
      ],
      "id": "6e8efc02-0d9d-4f73-90ab-226d15f5c277"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "### GNAR"
      ],
      "id": "519334e8-1a1d-4316-9036-93419e0e26de"
    },
    {
      "cell_type": "code",
      "execution_count": 35,
      "metadata": {},
      "outputs": [],
      "source": [
        "import rpy2\n",
        "import rpy2.robjects as ro \n",
        "from rpy2.robjects.vectors import FloatVector \n",
        "from rpy2.robjects.packages import importr"
      ],
      "id": "a6cc2c10-942a-448e-a2cc-bcc9fadbac6b"
    },
    {
      "cell_type": "code",
      "execution_count": 2,
      "metadata": {},
      "outputs": [],
      "source": [
        "%load_ext rpy2.ipython"
      ],
      "id": "511d4adc-5ec3-4fac-81d2-7457c8b9a9ba"
    },
    {
      "cell_type": "code",
      "execution_count": 3,
      "metadata": {},
      "outputs": [
        {
          "output_type": "stream",
          "name": "stderr",
          "text": [
            "R[write to console]: Loading required package: igraph\n",
            "\n",
            "R[write to console]: \n",
            "Attaching package: ‘igraph’\n",
            "\n",
            "\n",
            "R[write to console]: The following objects are masked from ‘package:stats’:\n",
            "\n",
            "    decompose, spectrum\n",
            "\n",
            "\n",
            "R[write to console]: The following object is masked from ‘package:base’:\n",
            "\n",
            "    union\n",
            "\n",
            "\n",
            "R[write to console]: Loading required package: wordcloud\n",
            "\n",
            "R[write to console]: Loading required package: RColorBrewer\n"
          ]
        }
      ],
      "source": [
        "%%R\n",
        "library(GNAR)\n",
        "library(igraph)"
      ],
      "id": "b9fb9a3b-1434-4993-9fc6-694585259fbe"
    },
    {
      "cell_type": "code",
      "execution_count": 4,
      "metadata": {},
      "outputs": [
        {
          "output_type": "stream",
          "name": "stdout",
          "text": [
            "GNARnet with 5 nodes and 10 edges\n",
            " of equal length  1"
          ]
        }
      ],
      "source": [
        "%%R\n",
        "summary(fiveNet)"
      ],
      "id": "c0beacdf-afd3-4810-ba3a-42fd300f703b"
    },
    {
      "cell_type": "code",
      "execution_count": 5,
      "metadata": {},
      "outputs": [
        {
          "output_type": "stream",
          "name": "stdout",
          "text": [
            "     [,1] [,2] [,3] [,4] [,5]\n",
            "[1,]    0    0    0    1    1\n",
            "[2,]    0    0    1    1    0\n",
            "[3,]    0    1    0    1    0\n",
            "[4,]    1    1    1    0    0\n",
            "[5,]    1    0    0    0    0"
          ]
        }
      ],
      "source": [
        "%%R\n",
        "edges <- as.matrix(fiveNet)\n",
        "edges"
      ],
      "id": "f4ded4e2-e43d-489c-beaf-cfe8345ab1c6"
    },
    {
      "cell_type": "code",
      "execution_count": 6,
      "metadata": {},
      "outputs": [
        {
          "output_type": "stream",
          "name": "stdout",
          "text": [
            "GNARnet with 5 nodes \n",
            "edges:1--4 1--5 2--3 2--4 3--2 3--4 4--1 4--2 4--3 5--1 \n",
            "     \n",
            " edges of each of length  1 "
          ]
        }
      ],
      "source": [
        "%%R\n",
        "print(fiveNet)"
      ],
      "id": "4a9bcfd8-59d2-496c-8826-5f1737dfcc32"
    },
    {
      "cell_type": "code",
      "execution_count": 7,
      "metadata": {},
      "outputs": [
        {
          "output_type": "stream",
          "name": "stdout",
          "text": [
            "Model: \n",
            "GNAR(2,[1,1]) \n",
            "\n",
            "Call:\n",
            "lm(formula = yvec ~ dmat + 0)\n",
            "\n",
            "Coefficients:\n",
            " dmatalpha1  dmatbeta1.1   dmatalpha2  dmatbeta2.1  \n",
            "    0.20624      0.50277      0.02124     -0.09523  \n"
          ]
        }
      ],
      "source": [
        "%%R\n",
        "data(\"fiveNode\")\n",
        "answer <- GNARfit(vts = fiveVTS, net = fiveNet, alphaOrder = 2, betaOrder = c(1, 1))\n",
        "answer"
      ],
      "id": "89bfe642-aaae-4e3d-9415-a86e63cc8bc4"
    },
    {
      "cell_type": "code",
      "execution_count": 8,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAeAAAAHgCAIAAADytinCAAAgAElEQVR4nOy9eXwc1Zn3e86pvao3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\nUkCgAQAAKAUEGgAAgFJAoAEAACjl/wHhU1Pu0Kqg9AAAAABJRU5ErkJggg==\n"
          }
        }
      ],
      "source": [
        "%%R\n",
        "layout(matrix(c(1,2,3,4), 2, 2, byrow = TRUE))\n",
        "plot(fiveVTS[, 1], ylab = \"Node A Time Series\")\n",
        "lines(fitted(answer)[, 1], col = 2)\n",
        "plot(fiveVTS[, 2], ylab = \"Node B Time Series\")\n",
        "lines(fitted(answer)[, 2], col = 2)\n",
        "plot(fiveVTS[, 3], ylab = \"Node C Time Series\")\n",
        "lines(fitted(answer)[, 3], col = 2)\n",
        "plot(fiveVTS[, 4], ylab = \"Node D Time Series\")\n",
        "lines(fitted(answer)[, 4], col = 2)"
      ],
      "id": "76751c27-f549-46a6-b64a-752b475470d8"
    },
    {
      "cell_type": "code",
      "execution_count": 9,
      "metadata": {},
      "outputs": [],
      "source": [
        "%R -o fiveVTS\n",
        "%R -o edges"
      ],
      "id": "17b5a6b6-09a0-4d01-8195-d029bfce33e3"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "-   node: 5\n",
        "-   time 200"
      ],
      "id": "362633ef-60b0-4cda-9909-fe0323d81751"
    },
    {
      "cell_type": "code",
      "execution_count": 19,
      "metadata": {},
      "outputs": [],
      "source": [
        "edges_tensor = torch.tensor(edges)"
      ],
      "id": "8879b846-89ce-465c-9fb5-39149fd26265"
    },
    {
      "cell_type": "code",
      "execution_count": 20,
      "metadata": {},
      "outputs": [],
      "source": [
        "nonzero_indices = edges_tensor.nonzero()"
      ],
      "id": "bf2a5fc6-f156-42b0-9b1b-78190fe38faf"
    },
    {
      "cell_type": "code",
      "execution_count": 21,
      "metadata": {},
      "outputs": [],
      "source": [
        "fiveNet_edge = np.array(nonzero_indices).T\n",
        "fiveNet_edge"
      ],
      "id": "7f7f7afa-9120-4410-9973-90d5dac39781"
    },
    {
      "cell_type": "code",
      "execution_count": 22,
      "metadata": {},
      "outputs": [],
      "source": [
        "fiveVTS.shape"
      ],
      "id": "84a87dcc-0ba7-4337-91ea-31246ba03c82"
    },
    {
      "cell_type": "code",
      "execution_count": 23,
      "metadata": {},
      "outputs": [],
      "source": [
        "T = 200\n",
        "N = 5 # number of Nodes\n",
        "E = fiveNet_edge\n",
        "V = np.array([1,2,3,4,5])\n",
        "t = np.arange(0,T)\n",
        "node_features = 1"
      ],
      "id": "8e1e6fcf-b3ab-4cfb-a0c3-8d9a0dec52b1"
    },
    {
      "cell_type": "code",
      "execution_count": 24,
      "metadata": {},
      "outputs": [],
      "source": [
        "f = torch.tensor(fiveVTS).reshape(200,5,1).float()"
      ],
      "id": "ec8a7baa-dbb5-4f96-b530-908b9b60d489"
    },
    {
      "cell_type": "code",
      "execution_count": 25,
      "metadata": {},
      "outputs": [],
      "source": [
        "X = f[:199,:,:]\n",
        "y = f[1:,:,:]"
      ],
      "id": "f871a195-03ef-4866-9ef8-f7647d2bc4eb"
    },
    {
      "cell_type": "code",
      "execution_count": 26,
      "metadata": {},
      "outputs": [],
      "source": [
        "edge_index = torch.tensor(E)\n",
        "edge_attr = torch.tensor(np.array([1,1,1,1,1,1,1,1,1,1]),dtype=torch.float32)"
      ],
      "id": "893cbe54-e4cc-4c03-9a15-b50204889441"
    },
    {
      "cell_type": "code",
      "execution_count": 27,
      "metadata": {},
      "outputs": [],
      "source": [
        "_ee = enumerate(zip(X,y))"
      ],
      "id": "8e7f44a1-f65e-473f-8488-ba5e00170d59"
    },
    {
      "cell_type": "code",
      "execution_count": 40,
      "metadata": {},
      "outputs": [
        {
          "output_type": "stream",
          "name": "stderr",
          "text": [
            "100%|█| 50/50 [00:34<00:00,  1.45it/"
          ]
        }
      ],
      "source": [
        "from tqdm import tqdm\n",
        "\n",
        "model = RecurrentGCN(node_features=1, filters=8)\n",
        "\n",
        "optimizer = torch.optim.Adam(model.parameters(), lr=0.05)\n",
        "\n",
        "model.train()\n",
        "\n",
        "for epoch in tqdm(range(50)):\n",
        "    for time, (xt,yt) in enumerate(zip(X,y)):\n",
        "        y_hat = model(xt, edge_index, edge_attr)\n",
        "        cost = torch.mean((y_hat-yt)**2)\n",
        "        cost.backward()\n",
        "        optimizer.step()\n",
        "        optimizer.zero_grad()"
      ],
      "id": "621abd3d-04ee-40fe-8e5b-6c58acfc3f4a"
    },
    {
      "cell_type": "code",
      "execution_count": 41,
      "metadata": {},
      "outputs": [],
      "source": [
        "yhat = torch.stack([model(xt, edge_index, edge_attr) for xt in X]).detach().numpy()"
      ],
      "id": "a9a3585b-9c87-4525-adc3-253ad9276a09"
    },
    {
      "cell_type": "code",
      "execution_count": 42,
      "metadata": {},
      "outputs": [],
      "source": [
        "yhat.shape"
      ],
      "id": "b17b5ab7-3aab-4dbc-a554-497c693e8f58"
    },
    {
      "cell_type": "code",
      "execution_count": 43,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXIAAAD5CAYAAAA6JL6mAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\n"
          }
        }
      ],
      "source": [
        "plt.plot(y[:,1])\n",
        "plt.plot(yhat[:,1].data)"
      ],
      "id": "07ce5944-a9cf-47b5-8cd9-410d96f254f4"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "### Wind network time series\n",
        "\n",
        "the data suite vswind that contains a number of R objects pertaining to\n",
        "721 wind speeds taken at each of 102 weather stations in England and\n",
        "Wales. The suite contains the vector time series vswindts, the\n",
        "associated network vswindnet, a character vector of the weather station\n",
        "location names in vswindnames and coordinates of the stations in the two\n",
        "column matrix vswindcoords. The data originate from the UK Met Office\n",
        "site http://wow.metoffice.gov.uk and full details can be found in the\n",
        "vswind help file in the GNAR package."
      ],
      "id": "35b5a623-524f-45af-bfe9-cf90b1e8c14b"
    },
    {
      "cell_type": "code",
      "execution_count": 151,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAeAAAAHgCAIAAADytinCAAAgAElEQVR4nOydeSBU6xvHH1tlGwbJ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\n"
          }
        }
      ],
      "source": [
        "%%R\n",
        "oldpar <- par(cex = 0.75)\n",
        "windnetplot()\n",
        "par(oldpar)"
      ],
      "id": "70c1835d-b968-4b3f-bd2e-1ae1b42485e8"
    },
    {
      "cell_type": "code",
      "execution_count": 167,
      "metadata": {},
      "outputs": [],
      "source": [
        "%%R\n",
        "edges_wind <- as.matrix(vswindnet)"
      ],
      "id": "71b16063-4f69-4517-b7e2-c22c90a1114d"
    },
    {
      "cell_type": "code",
      "execution_count": 168,
      "metadata": {},
      "outputs": [],
      "source": [
        "%R -o vswindts\n",
        "%R -o edges_wind"
      ],
      "id": "60857cbd-3186-4171-9254-f3782263c92d"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "-   nodes : 102\n",
        "-   time step : 721"
      ],
      "id": "75cf264e-8d2b-46b7-b22d-920e49b25f3c"
    },
    {
      "cell_type": "code",
      "execution_count": 155,
      "metadata": {},
      "outputs": [],
      "source": [
        "vswindts.shape"
      ],
      "id": "f19812e3-0bdc-4c5b-9011-fe1c7e44fedf"
    },
    {
      "cell_type": "code",
      "execution_count": 288,
      "metadata": {},
      "outputs": [],
      "source": [
        "edges_wind.shape"
      ],
      "id": "fee186af-e08f-403b-bc6a-48b3b538be04"
    },
    {
      "cell_type": "code",
      "execution_count": 214,
      "metadata": {},
      "outputs": [],
      "source": [
        "edges_winds = torch.tensor(edges_wind)"
      ],
      "id": "350e21dd-ea56-4279-a9b3-645fc4f32777"
    },
    {
      "cell_type": "code",
      "execution_count": 215,
      "metadata": {},
      "outputs": [],
      "source": [
        "nonzero_indices_wind = edges_winds.nonzero()"
      ],
      "id": "7ca2da26-6d30-47e8-b0e2-ac2e98a7055a"
    },
    {
      "cell_type": "code",
      "execution_count": 296,
      "metadata": {},
      "outputs": [],
      "source": [
        "vswindnet_edge = np.array(nonzero_indices_wind).T\n",
        "vswindnet_edge.shape"
      ],
      "id": "ce9ec873-91f1-4f12-9a2a-96dfc5304e31"
    },
    {
      "cell_type": "code",
      "execution_count": 293,
      "metadata": {},
      "outputs": [],
      "source": [
        "T = 721\n",
        "N = 102 # number of Nodes\n",
        "E = vswindnet_edge\n",
        "V = np.array(range(101))\n",
        "t = np.arange(0,T)\n",
        "node_features = 1"
      ],
      "id": "2efaf3cd-7823-40bb-8b28-edf97f5a6cbb"
    },
    {
      "cell_type": "code",
      "execution_count": 297,
      "metadata": {},
      "outputs": [],
      "source": [
        "f = torch.tensor(vswindts).reshape(721,102,1).float()"
      ],
      "id": "fefa2ba9-2e0f-4eef-b18f-59bd834f7f0a"
    },
    {
      "cell_type": "code",
      "execution_count": 298,
      "metadata": {},
      "outputs": [],
      "source": [
        "X = f[:720,:,:]\n",
        "y = f[1:,:,:]"
      ],
      "id": "3e031cf5-8e19-46c9-a119-43844a1ae3e6"
    },
    {
      "cell_type": "code",
      "execution_count": 300,
      "metadata": {},
      "outputs": [],
      "source": [
        "edge_index = torch.tensor(E)\n",
        "edge_attr = torch.tensor(np.array([1]*202),dtype=torch.float32)"
      ],
      "id": "a430804a-d035-4abe-89f8-7295a50721db"
    },
    {
      "cell_type": "code",
      "execution_count": 301,
      "metadata": {},
      "outputs": [],
      "source": [
        "_ee = enumerate(zip(X,y))"
      ],
      "id": "80392d84-d880-4731-83a1-4c8db60f3e8e"
    },
    {
      "cell_type": "code",
      "execution_count": 302,
      "metadata": {},
      "outputs": [
        {
          "output_type": "stream",
          "name": "stderr",
          "text": [
            "100%|██████████| 50/50 [02:16<00:00,  2.73s/it]"
          ]
        }
      ],
      "source": [
        "from tqdm import tqdm\n",
        "\n",
        "model = RecurrentGCN(node_features=1, filters=4)\n",
        "\n",
        "optimizer = torch.optim.Adam(model.parameters(), lr=0.01)\n",
        "\n",
        "model.train()\n",
        "\n",
        "for epoch in tqdm(range(50)):\n",
        "    for time, (xt,yt) in enumerate(zip(X,y)):\n",
        "        y_hat = model(xt, edge_index, edge_attr)\n",
        "        cost = torch.mean((y_hat-yt)**2)\n",
        "        cost.backward()\n",
        "        optimizer.step()\n",
        "        optimizer.zero_grad()"
      ],
      "id": "325c70fd-2d38-4a9a-8700-7298d3646a96"
    },
    {
      "cell_type": "code",
      "execution_count": 303,
      "metadata": {},
      "outputs": [],
      "source": [
        "yhat = torch.stack([model(xt, edge_index, edge_attr) for xt in X]).detach().numpy()"
      ],
      "id": "fdb0beda-746d-4c90-9306-14fe72da68e8"
    },
    {
      "cell_type": "code",
      "execution_count": 304,
      "metadata": {},
      "outputs": [],
      "source": [
        "yhat.shape"
      ],
      "id": "863c16da-ebb0-4235-9fe3-4fce461fd7ba"
    },
    {
      "cell_type": "code",
      "execution_count": 305,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXQAAAD4CAYAAAD8Zh1EAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\n"
          }
        }
      ],
      "source": [
        "plt.plot(y[:,1])\n",
        "plt.plot(yhat[:,1].data)"
      ],
      "id": "5eb6f08d-bff6-4937-9cd4-59d8c74aa369"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "### OECD GDP\n",
        "\n",
        "**해당예제는 GNAR 패키지에서 네트워크(엣지)를 맞추는 예제로서 나옴,\n",
        "그렇기에 네트워크 존재하지 않아 연구 예제로서 사용하지 않을 예정**\n",
        "\n",
        "이 데이터는 네트워크를 추정하여 fit 및 predict함\n",
        "\n",
        "GOP growth rate time series\n",
        "\n",
        "-   35 countries from the OECD website\n",
        "\n",
        "-   time series : 1961 - 2013\n",
        "\n",
        "-   T = 52\n",
        "\n",
        "-   Nodes = 35\n",
        "\n",
        "-   In this data set 20.8% (379 out of 1820) of the observations were\n",
        "    missing due to some nodes not being included from the start."
      ],
      "id": "7fff674e-8774-495b-a543-5cfd7ad34fd0"
    },
    {
      "cell_type": "code",
      "execution_count": 157,
      "metadata": {},
      "outputs": [],
      "source": [
        "%%R\n",
        "library(\"fields\")"
      ],
      "id": "e6cb74d3-317a-4d98-a21a-bdf65267dfe5"
    },
    {
      "cell_type": "code",
      "execution_count": 158,
      "metadata": {},
      "outputs": [],
      "source": [
        "%R -o gdpVTS"
      ],
      "id": "d37591fc-cb83-49d9-b196-44622d65b1e4"
    },
    {
      "cell_type": "code",
      "execution_count": 159,
      "metadata": {},
      "outputs": [],
      "source": [
        "gdpVTS.shape"
      ],
      "id": "59436894-2b2a-4c4b-a4cf-a0e89b0220a9"
    },
    {
      "cell_type": "code",
      "execution_count": 173,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXIAAAD4CAYAAADxeG0DAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\n8EDO4XA4Aed/Acsi/aj6oP63AAAAAElFTkSuQmCC\n"
          }
        }
      ],
      "source": [
        "plt.plot(gdpVTS[:,1])"
      ],
      "id": "34a40c8b-18d8-433c-9a06-c51c6bca0209"
    }
  ],
  "nbformat": 4,
  "nbformat_minor": 5,
  "metadata": {
    "kernelspec": {
      "name": "python3",
      "display_name": "Python 3 (ipykernel)",
      "language": "python"
    },
    "language_info": {
      "name": "python",
      "codemirror_mode": {
        "name": "ipython",
        "version": "3"
      },
      "file_extension": ".py",
      "mimetype": "text/x-python",
      "nbconvert_exporter": "python",
      "pygments_lexer": "ipython3",
      "version": "3.8.12"
    }
  }
}